using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using CyDesigner.Extensions.Common;
using CyDesigner.Extensions.Gde;

// The namespace is required to have the same name as the component for a customizer.
namespace dummy_app
{
    // CyCustomizer is the required class name for a customizer.
    public class CyCustomizer : ICyParamEditHook_v1
    {
        #region ICyParamEditHook_v1 Members
        
        // Type of dialog box. Advanced opens with a button on the generic form.  Complete opens immediately
        CyCompDevParamEditorMode m_mode = CyCompDevParamEditorMode.COMPLETE;
        // Run Instance Customizer on Instance Selection
        bool m_editOnDrop = false;
        
        //Form m_Form;

        /// <summary>
        /// Gets the <see cref="CyCompDevParamEditorMode"/> that specifies the level of customization provided by
        /// this class.
        /// </summary>
        /// 
        /// <returns>
        /// Returns the <see cref="CyCompDevParamEditorMode"/> that specifies the level of customization provided by
        /// this class.
        /// </returns>
        CyCompDevParamEditorMode ICyParamEditHook_v1.GetEditorMode()
        {
            return m_mode;
        }

        /// <summary>
        /// Configures an instance.
        /// </summary>
        /// 
        /// <param name="edit">
        /// Allows editing access to the instance being edited.
        /// </param>
        /// 
        /// <param name="termQuery">
        /// Allows querying access to the terminals and their connections on the instance being edited.
        /// </param>
        /// 
        /// <param name="mgr">
        /// Allows editing access to the express instance being edited.
        /// </param>
        /// 
        /// <returns>
        /// Returns DialogResult.Ok if the changes made by calling this method should be committed, otherwise
        /// it should return DialogResult.Cancel and any changes made by this method will be discarded.
        /// </returns>
        DialogResult ICyParamEditHook_v1.EditParams(
            ICyInstEdit_v1 obj,
            ICyTerminalQuery_v1 termQuery,
            ICyExpressMgr_v1 mgr)
        {
            // ICyTabbedParamEditor: Defines a parameter editor that can be
            // used to edit the parameters that exit on an instance.
            // This editor consist of multiple tab pages hosted inside a 
            // dialog. The dialog includes the following buttons:
            // OK, Apply, Cancel and Datasheet.
            //ICyTabbedParamEditor editor = obj.CreateTabbedParamEditor();
            //m_Form = new Form(obj);
            //editor.AddCustomPage("nRF24 Configuration", m_Form, ExpView_ParamChanged, "nRF24 Configuration");
            //editor.AddDefaultPage("Built-in", "Built-in");
            
            ICyParamEditor editor = obj.CreateParamEditor(new Form(obj));
            
            return editor.ShowDialog();
        }
        
        //private bool m_internalChanges;
        //ICyInstEdit_v1 m_component;
        
        private void ExpView_ParamChanged(ICyParamEditor custEditor, CyCompDevParam param)
        {
            if (param.ErrorCount == 0)
            {
                /*
                            m_internalChanges = true;
                            // this class holds all of the information for
                            // a parameter in psoc creator
                            CyCompDevParam param;
                            // Update Customizer controls to match parameters
                            param = m_component.GetCommittedParam(CR_PARAM);
                            if (param.ErrorCount == 0)
                                crCheckBox.Checked = Convert.ToBoolean(param.Value);

                            param = m_component.GetCommittedParam(CUSTOM_CHARACTER_SET_PARAM);
                            if (param.ErrorCount == 0)
                            {
                                switch ((CyCustomCharacterSetTypes) byte.Parse(param.Value))
                                {
                                    case CyCustomCharacterSetTypes.HORIZONTAL:
                                        hbgRadioButton.Checked = true;
                                        break;
                                    case CyCustomCharacterSetTypes.VERTICAL:
                                        vbgRadioButton.Checked = true;
                                        break;
                                    case CyCustomCharacterSetTypes.USERDEFINED:
                                        udRadioButton.Checked = true;
                                        break;
                                    default:
                                        noneRadioButton.Checked = true;
                                        break;
                                }
                            }

                            m_internalChanges = false;
                */
            }
        }

        /// <summary>
        /// Gets whether or not to make a call to EditParams as soon as a
        /// component is dropped on to the schematic from the Component Catalog.
        /// </summary>
        bool ICyParamEditHook_v1.EditParamsOnDrop
        {
            get { return m_editOnDrop;}
        }

        #endregion
    }
}

//[] END OF FILE
